@@ -2,13 +2,12 @@ import logging
 import warnings
 from typing import Tuple
 
-from jaraco.collections import DictAdapter, Projection
 from jaraco.classes.ancestry import iter_subclasses
-from jaraco.itertools import always_iterable
 
 import jaraco
 from ..helpers import errors as ERROR
 from ..helpers import urls
+from ..state import Stateful
 from .control import needs_control_url
 from . import pkg
 
@@ -16,21 +15,12 @@ from . import pkg
 log = logging.getLogger(__name__)
 
 
-class Device:
+class Device(Stateful):
     """Class to represent each Abode device."""
 
     tags: Tuple[str, ...] = ()
-
-    def __init__(self, state, client):
-        """Set up Abode device."""
-        self._state = state
-        self._client = client
-
-    def __getattr__(self, name):
-        try:
-            return self._state[name]
-        except KeyError as exc:
-            raise AttributeError(name) from exc
+    _desc_t = '{name} (ID: {id}, UUID: {uuid}) - {type} - {status}'
+    _url_t = urls.DEVICE
 
     @needs_control_url
     def set_status(self, status):
@@ -82,30 +72,6 @@ class Device:
         """Get a value from the device state."""
         return self._state.get(name.lower(), {})
 
-    def refresh(self, path=urls.DEVICE):
-        """Refresh the device state.
-
-        Useful when not using the notification service.
-        """
-        path = path.format(device_id=self.id)
-
-        response = self._client.send_request(method="get", path=path)
-        state = list(always_iterable(response.json()))
-
-        log.debug("Device Refresh Response: %s", response.text)
-
-        for device in state:
-            self.update(device)
-
-        return state
-
-    def update(self, json_state):
-        """Update the json data from a dictionary.
-
-        Only updates keys already present.
-        """
-        self._state.update(Projection(self._state, json_state))
-
     @property
     def status(self):
         """Shortcut to get the generic status of a device."""
@@ -152,12 +118,6 @@ class Device:
         )
         return self.uuid
 
-    @property
-    def desc(self):
-        """Get a short description of the device."""
-        tmpl = '{name} (ID: {id}, UUID: {uuid}) - {type} - {status}'
-        return tmpl.format_map(DictAdapter(self))
-
     @staticmethod
     def resolve_type_unknown(state):
         if state['generic_type'] != 'unknown':
