@@ -1,29 +1,29 @@
 """Abode lock device."""
 
-from ..helpers import constants as CONST
+from . import status as STATUS
 from . import base
 
 
 class Lock(base.Device):
     """Class to represent a door lock."""
 
-    implements = CONST.TYPE_LOCK
+    tags = ('door_lock',)
 
     def lock(self):
         """Lock the device."""
-        success = self.set_status(CONST.STATUS_LOCKCLOSED_INT)
+        success = self.set_status(int(STATUS.Lock.CLOSED))
 
         if success:
-            self._state['status'] = CONST.STATUS_LOCKCLOSED
+            self._state['status'] = STATUS.Lock.CLOSED
 
         return success
 
     def unlock(self):
         """Unlock the device."""
-        success = self.set_status(CONST.STATUS_LOCKOPEN_INT)
+        success = self.set_status(int(STATUS.Lock.OPEN))
 
         if success:
-            self._state['status'] = CONST.STATUS_LOCKOPEN
+            self._state['status'] = STATUS.Lock.OPEN
 
         return success
 
@@ -34,4 +34,4 @@ class Lock(base.Device):
 
         Err on side of caution, assume if lock isn't closed then it's open.
         """
-        return self.status in CONST.STATUS_LOCKCLOSED
+        return self.status in STATUS.Lock.CLOSED
