@@ -61,7 +61,7 @@ class TestHue:
         assert not device.is_on
 
         # Set up our direct device get url
-        device_url = urls.DEVICE.format(device_id=HUE.DEVICE_ID)
+        device_url = urls.DEVICE.format(id=HUE.DEVICE_ID)
 
         # Change device properties
         m.get(
